==> plantuml-libs-9.0.0.tgz: package/distribution/simpleicons-7/W/Worldhealthorganization.md <==
# Worldhealthorganization


```text
simpleicons-7/W/Worldhealthorganization
```

```text
include('simpleicons-7/W/Worldhealthorganization')
```



| Illustration | Worldhealthorganization |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/W/Worldhealthorganization.png) | ![illustration for Worldhealthorganization](../../simpleicons-7/W/Worldhealthorganization.Local.png) |




## Worldhealthorganization

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Worldhealthorganization
include('simpleicons-7/W/Worldhealthorganization')

' renders the element
Worldhealthorganization('Worldhealthorganization', 'Worldhealthorganization', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Worldhealthorganization
include('simpleicons-7/W/Worldhealthorganization')

' renders the element
Worldhealthorganization('Worldhealthorganization', 'Worldhealthorganization', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/simpleicons-7/W/Worldhealthorganization.md <==
# Worldhealthorganization


```text
simpleicons-7/W/Worldhealthorganization
```

```text
include('simpleicons-7/W/Worldhealthorganization')
```



| Illustration | Worldhealthorganization |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/W/Worldhealthorganization.png) | ![illustration for Worldhealthorganization](../../simpleicons-7/W/Worldhealthorganization.Local.png) |




## Worldhealthorganization

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Worldhealthorganization
include('simpleicons-7/W/Worldhealthorganization')

' renders the element
Worldhealthorganization('Worldhealthorganization', 'Worldhealthorganization', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Worldhealthorganization
include('simpleicons-7/W/Worldhealthorganization')

' renders the element
Worldhealthorganization('Worldhealthorganization', 'Worldhealthorganization', 'an optional tech label', 'an optional description')
@enduml
```
